@@ -8,9 +8,10 @@ knitr::opts_chunk$set(
 ## ----setup, echo=FALSE, messages=FALSE, warnings=FALSE--------------------------------------------
 suppressPackageStartupMessages({
     library(ChemmineR)
-    library(ChemmineOB)
     library(fmcsR)
     library(ggplot2)
+	 #library(ChemmineOB)
+	
 })
 
 ## ----eval=FALSE-----------------------------------------------------------------------------------
@@ -118,32 +119,32 @@ atomblock(sdfset[[1]])[1:4,]
 ## ----eval=FALSE, tidy=FALSE-----------------------------------------------------------------------
 #  propOB(sdfset[1])
 
-## ----eval=TRUE, tidy=FALSE------------------------------------------------------------------------
-fingerprintOB(sdfset,"FP2")
+## ----eval=FALSE, tidy=FALSE-----------------------------------------------------------------------
+#  fingerprintOB(sdfset,"FP2")
 
-## ----eval=TRUE, tidy=FALSE------------------------------------------------------------------------
-#count rotable bonds
-smartsSearchOB(sdfset[1:5],"[!$(*#*)&!D1]-!@[!$(*#*)&!D1]",uniqueMatches=FALSE)
+## ----eval=FALSE, tidy=FALSE-----------------------------------------------------------------------
+#  #count rotable bonds
+#  smartsSearchOB(sdfset[1:5],"[!$(*#*)&!D1]-!@[!$(*#*)&!D1]",uniqueMatches=FALSE)
 
-## ----eval=TRUE, tidy=FALSE------------------------------------------------------------------------
-exactMassOB(sdfset[1:5])
+## ----eval=FALSE, tidy=FALSE-----------------------------------------------------------------------
+#  exactMassOB(sdfset[1:5])
 
-## ----eval=TRUE, tidy=FALSE,fig.height=5,fig.width=5-----------------------------------------------
-sdfset2 = regenerateCoords(sdfset[1:5])
+## ----eval=FALSE, tidy=FALSE,fig.height=5,fig.width=5----------------------------------------------
+#  sdfset2 = regenerateCoords(sdfset[1:5])
+#  
+#  plot(sdfset[1], regenCoords=TRUE,print=FALSE)
 
-plot(sdfset[1], regenCoords=TRUE,print=FALSE)
-
-## ----eval=TRUE, tidy=FALSE, dev='svg',fig.height=5,fig.width=5------------------------------------
-openBabelPlot(sdfset[4],regenCoords=TRUE)
+## ----eval=FALSE, tidy=FALSE, dev='svg',fig.height=5,fig.width=5-----------------------------------
+#  openBabelPlot(sdfset[4],regenCoords=TRUE)
 
 ## ----eval=FALSE, tidy=FALSE-----------------------------------------------------------------------
 #  sdf3D = generate3DCoords(sdfset[1])
 
-## ----eval=TRUE, tidy=FALSE------------------------------------------------------------------------
-canonicalSdf= canonicalize(sdfset[1])
+## ----eval=FALSE, tidy=FALSE-----------------------------------------------------------------------
+#  canonicalSdf= canonicalize(sdfset[1])
 
-## ----eval=TRUE, tidy=FALSE------------------------------------------------------------------------
-mapping = canonicalNumbering(sdfset[1])
+## ----eval=FALSE, tidy=FALSE-----------------------------------------------------------------------
+#  mapping = canonicalNumbering(sdfset[1])
 
 ## ----eval=FALSE, tidy=FALSE-----------------------------------------------------------------------
 #   sdfset <- read.SDFset("http://faculty.ucr.edu/~tgirke/Documents/R_BioCond/Samples/sdfsample.sdf")
@@ -484,10 +485,10 @@ getCompoundFeatures(conn,results[1:5],c("rings","aromatic"),keepOrder=TRUE)
 ## ----plotstruct4, eval=TRUE, tidy=FALSE-----------------------------------------------------------
  plot(sdfset[1], print=FALSE, colbonds=c(22,26,25,3,28,27,2,23,21,18,8,19,20,24)) 
 
-## ----datatable, eval=TRUE, tidy=FALSE-------------------------------------------------------------
-data(sdfsample)
-SDFDataTable(sdfsample[1:5])
-
+## ----datatable, eval=FALSE, tidy=FALSE------------------------------------------------------------
+#  data(sdfsample)
+#  SDFDataTable(sdfsample[1:5])
+#  
 
 ## ----eval=FALSE, tidy=FALSE-----------------------------------------------------------------------
 #   sdf.visualize(sdfset[1:4])
